FocusCause

Enum FocusCause 

pub enum FocusCause {
    Navigated,
    Pressed,
}
The cause for a FocusGained

Sometimes widgets would like to know how their focus was gained so they can act accordingly.

For example, a text input may want to select all text when navigated into, but not when pressed.

Variants



Navigated

The input was navigated into by the keyboard, gamepad, or default behavior when unknown.



Pressed

The input was pressed into with the mouse or touchpad

This is only sent for primary mouse presses. Focus gained from other mouse buttons or gestures will be Navigated.