pub struct InputFocus { /* private fields */ }Expand description
Resource representing which entity has input focus, if any. Input events (other than pointer-like inputs) will be dispatched to the current focus entity, or to the primary window if no entity has focus.
Changing the input focus is as easy as modifying this resource.
To detect when an entity gains or loses focus, listen for the FocusGained and FocusLost events.
Examples
From within a system:
use bevy_ecs::prelude::*;
use bevy_input_focus::{FocusCause, InputFocus};
fn clear_focus(mut input_focus: ResMut<InputFocus>) {
input_focus.clear();
}With exclusive (or deferred) world access:
use bevy_ecs::prelude::*;
use bevy_input_focus::{FocusCause, InputFocus};
fn set_focus_from_world(world: &mut World) {
let entity = world.spawn_empty().id();
// Fetch the resource from the world
let mut input_focus = world.resource_mut::<InputFocus>();
// Then mutate it!
input_focus.set(entity, FocusCause::Navigated);
// Or you can just insert a fresh copy of the resource
// which will overwrite the existing one.
world.insert_resource(InputFocus::from_entity(entity));
}Implementations
Sourceimpl InputFocus
impl InputFocus
Sourcepub fn from_entity(entity: Entity) -> Self
pub fn from_entity(entity: Entity) -> Self
Create a new InputFocus resource with the given entity.
This is mostly useful for tests.
WARNING: this will clear any buffered focus changes,
so it may cause missed FocusGained and FocusLost events.
Prefer the set method for normal use, which will preserve buffered changes.
Sourcepub fn set(&mut self, entity: Entity, cause: FocusCause)
pub fn set(&mut self, entity: Entity, cause: FocusCause)
Set the entity with input focus.
When spawning entities, you may want to use the AutoFocus component instead,
which will automatically set focus to the entity when it is spawned.
This is particularly useful when working with bsn! scenes, where spawning may be delayed.