pub struct InputFocusPlugin;Expand description
Plugin which sets up the core input focus system.
This includes theInputFocus and InputFocusVisible resources,
set_initial_focus system to initialize the focus to the primary window, if any, at startup,
and process_recorded_focus_changes to send FocusGained and FocusLost events when the focused entity changes.